@@ -1,15 +1,11 @@
 import os
-import sys
 import types
 from collections.abc import MutableSequence
 from functools import total_ordering
-from typing import Tuple, Type
 
-__version__ = "1.2.0"
+__version__ = "1.7.0"
 
-__all__ = (
-    "FrozenList", "PyFrozenList"
-)  # type: Tuple[str, ...]
+__all__ = ("FrozenList", "PyFrozenList")  # type: Tuple[str, ...]
 
 
 NO_EXTENSIONS = bool(os.environ.get("FROZENLIST_NO_EXTENSIONS"))  # type: bool
@@ -17,15 +13,8 @@ NO_EXTENSIONS = bool(os.environ.get("FROZENLIST_NO_EXTENSIONS"))  # type: bool
 
 @total_ordering
 class FrozenList(MutableSequence):
-
     __slots__ = ("_frozen", "_items")
-
-    if sys.version_info >= (3, 9):
-        __class_getitem__ = classmethod(types.GenericAlias)
-    else:
-        @classmethod
-        def __class_getitem__(cls: Type["FrozenList"]) -> Type["FrozenList"]:
-            return cls
+    __class_getitem__ = classmethod(types.GenericAlias)
 
     def __init__(self, items=None):
         self._frozen = False
@@ -76,8 +65,7 @@ class FrozenList(MutableSequence):
         self._items.insert(pos, item)
 
     def __repr__(self):
-        return "<FrozenList(frozen={}, {!r})>".format(self._frozen,
-                                                      self._items)
+        return f"<FrozenList(frozen={self._frozen}, {self._items!r})>"
 
     def __hash__(self):
         if self._frozen:
@@ -89,9 +77,10 @@ class FrozenList(MutableSequence):
 PyFrozenList = FrozenList
 
 
-try:
-    from ._frozenlist import FrozenList as CFrozenList  # type: ignore
-    if not NO_EXTENSIONS:  # pragma: no cover
+if not NO_EXTENSIONS:
+    try:
+        from ._frozenlist import FrozenList as CFrozenList  # type: ignore
+    except ImportError:  # pragma: no cover
+        pass
+    else:
         FrozenList = CFrozenList  # type: ignore
-except ImportError:  # pragma: no cover
-    pass
